@@ -2,7 +2,7 @@
 import pandas as pd
 from dateutil.relativedelta import relativedelta
 
-from amendment_forecast import utils
+import utils
 from amendment_forecast.models import DATE_COLUMN_NAME, VALUE_COLUMN_NAME, initialize_model
 
 FREQUENCY_MAPPING = {
@@ -30,7 +30,7 @@ def run_forecast_ensemble(
         forecast_horizon_years,
         aggregate_operation="sum",
         training_holdout_pct=0.3,
-        frequency="weekly",
+        frequency="week",
         period_format=None):
     # Initialize with copy of input date
     df = dataframe.copy()
@@ -59,8 +59,8 @@ def run_forecast_ensemble(
         # "FBProphet",
         # "Naive",
         # "XGBoost",
-        "RandomForest",
-        # "SARIMA"
+        # "RandomForest",
+        "SARIMA"
     ]
 
     # For each model, run a full evaluation and add to the ensemble results
@@ -104,13 +104,17 @@ def run_forecast_ensemble(
     consolidated_metrics = utils.consolidate_scores(performance_metrics, ensemble_actuals.mean())
 
     degraded_accuracies = {}
-    prediction_years = (df[DATE_COLUMN_NAME].max() - df[DATE_COLUMN_NAME].min()).days / 365
-    for year in range(0, forecast_horizon_years):
-        if year > prediction_years:
-            years_outside_of_training = year - prediction_years
-            degraded_accuracies[year] = (0.95 ** years_outside_of_training) * consolidated_metrics["composite"]
-        else:
-            degraded_accuracies[year] = consolidated_metrics["composite"]
+    training_years = (df[DATE_COLUMN_NAME].max() - df[DATE_COLUMN_NAME].min()).days / 365
+    for year in range(1, forecast_horizon_years + 1):
+        multiplier = 1.0
+        years_outside_of_training = max(year - training_years, 0)
+        if years_outside_of_training > 0:
+            for yy in range(1, int(year) + 1):
+                if yy > (2 * training_years):
+                    multiplier *= 0.5
+                elif yy > training_years:
+                    multiplier *= 0.95
+        degraded_accuracies[year] = multiplier * consolidated_metrics["composite"]
 
     ensemble.append({
         "name": "ensemble",
